/***********************************************************************/
/*                                                                     */
/*  FILE        :ICS_sample.c                                          */
/*  DATE        :Feb, 10, 2018                                          */
/*  DESCRIPTION :Main Program                                          */
/*  CPU TYPE    :RX66T                                                 */
/*                                                                     */
/*  NOTE:THIS IS AN ICS++ EXAMPLE.                                     */
/*                                                                     */
/***********************************************************************/

#ifdef  __ICCRX__
  #include "r_cg_macrodriver.h"
  #include <math.h>
#elif   __CCRX__
  #include <machine.h>
  #include <mathf.h>
  #include <stdint.h>
  #include "iodefine.h"
#else
  //
#endif

#include "ICS2_RX66T.h"

void main(void);

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* Set option bytes */

#ifdef   __ICCRX__

  #if __LITTLE_ENDIAN__
    #pragma public_equ="__MDES",0xFFFFFFFFUL
  #else
    #pragma public_equ="__MDES",0xFFFFFFF8UL
  #endif

  #pragma public_equ="__OFS0",0xFFFFFFFFUL
  #pragma public_equ="__OFS1",0xFFFFFFFFUL

#elif   __CCRX__  
  
  
#endif


#define   TWOPI    (2.0f*3.1415926535f)
#define   BRR    0     //  HOCO=16MHz PLL=x10 = CPUCLK=160MHz, BRR=0, ICS=5Mbps, CLK=40MHz
                       //  BRR  BPS   DTLclock 
                       //   0  5.000M   40MHz  
                       //   1  2.500M   20MHz  
                       //   2  1.667M   13.333MHz
                       //   3  1.250M   10MHz    
                       //   4  1.000M    8MHz
#define   MODE   3     // 0:16bit 8ch,one time (Can not use)
                       // 1:32bit 8ch,2 times
                       // 2:32bit 4ch,one time
                       // 3:32bit 12ch 3 times


#ifdef  __ICCRX__
  #pragma location=0x0F000
  __no_init  uint32_t dtc_table[256]; /* alignment 0x000 */
#elif   __CCRX__
  #pragma address dtc_table=0x0F000
  uint32_t dtc_table[256];            /* alignment 0x000 */
#else
#endif

float   wt    = 0.0f;
float   dwt   = TWOPI*50.0f/10000.0f;
float   refu  = 0.0f;
float   refv  = 0.0f;
float   refw  = 0.0f;
float   m     = 1.0f;
float   dm    = 0.0002;
int32_t up    = 0;


void main(void)
{
    SYSTEM.PRCR.WORD = 0xA50B;
    SYSTEM.OSTDCR.BYTE = 0x00;

    SYSTEM.HOCOCR2.BYTE = 0x00;      // HOCO = 16MHz
    SYSTEM.HOCOCR.BYTE  = 0x00;      // HOCO start
    while (SYSTEM.OSCOVFSR.BIT.HCOVF==0) { /* no code */ }  // Wait until HOCO stable
    
    SYSTEM.SCKCR3.WORD = 0x0100;     // Set system clock = HOCO
    SYSTEM.SCKCR.LONG  = 0x20821222; // FCK=1/4, ICK=1/1, BCLK output stop, BCK=1/4
                                     // FCK  =1/4 =  40MHz            (Max 60MHz
                                     // ICK  =1/1 = 160MHz            (Max160MHz)
                                     // PCLKA=1/2 =  80MHz, SCIF,MTU,GPT (Max120MHz)
                                     // PCLKB=1/4 =  40MHz, others    (Max 60MHz)
                                     // PCLKC=1/4 =  40MHz, ADC unit0 (Max160MHz)
                                     // PCLKD=1/4 =  40MHz, ADC unit1 (Max 60MHz)
    SYSTEM.MEMWAIT.BYTE = 0x01;      // Force 1 wait for higher clock

    SYSTEM.PLLCR.BIT.PLIDIV    = 0;  // PLL input is divided by 1
    SYSTEM.PLLCR.BIT.PLLSRCSEL = 1;  // PLL source is HOCO
    SYSTEM.PLLCR.BIT.STC       = 19; // PLL mul rate is x10
    SYSTEM.PLLCR2.BYTE         = 0;  // PLL on
    while (SYSTEM.OSCOVFSR.BIT.PLOVF==0) { /* no code */ } // Wait until PLL stable
    
    SYSTEM.SCKCR3.WORD = 0x0400;     // Set system clock = PLL (16MHzx10=160MHz)

  //******************************************************************************************************
                                                                     // RENESAS   DTL    DTL
                                                                     //CPU Card  T5211  T6211
                                                                     //  100pin  100pin 112pin
    ics2_init((void *)(&dtc_table), ICS_SCI6_PB0_PB1, 6, BRR, MODE); //  CN6      CN9   CN5   OKOK (default) 5Mbps
  //ics2_init((void *)(&dtc_table), ICS_SCI5_PB5_PB6, 6, BRR, MODE); //  CN2      CN12  CN8   OKOK
  //ics2_init((void *)(&dtc_table), ICS_SCI1_PD3_PD5, 6, BRR, MODE); //  CN4      CN8   CN10    OK   // E1
  //ics2_init((void *)(&dtc_table), ICS_SCI12_PB5_PB6, 6, BRR, MODE);//   --      CN12  CN8     OK   
 
  //ics2_init((void *)(&dtc_table), ICS_SCI5_PD7_PE0, 6, BRR, MODE); //   --      CN10  CN14  --OK   // E1
  //ics2_init((void *)(&dtc_table), ICS_SCI8_PD0_PD1, 6, BRR, MODE); //   --      CN13  CN11  --OK
  //ics2_init((void *)(&dtc_table), ICS_SCI8_PC1_PC0, 6, BRR, MODE); //   --      --    CN7   --OK
  //ics2_init((void *)(&dtc_table), ICS_SCI8_PA4_PA5, 6, BRR, MODE); //   --      CN6   CN6   --OK
  //ics2_init((void *)(&dtc_table), ICS_SCI8_P23_P22, 6, BRR, MODE); //   --      CN1   CN12  --OK  
  //ics2_init((void *)(&dtc_table), ICS_SCI9_P01_P00, 6, BRR, MODE); //   --      CN11  CN15  --OK  
  //ics2_init((void *)(&dtc_table), ICS_SCI9_PA3_PA2, 6, BRR, MODE); //   --      CN4   CN4   --OK  
  //ics2_init((void *)(&dtc_table), ICS_SCI9_PG1_PG0, 6, BRR, MODE); //   --            CN9   --OK  
  //ics2_init((void *)(&dtc_table), ICS_SCI12_P23_P22, 6, BRR, MODE); //  --      CN1   CN12  --OK
  //ics2_init((void *)(&dtc_table), ICS_SCI12_P01_P00, 6, BRR, MODE); //  --      CN11  CN15  --OK
    
  //******************************************************************************************************

#ifdef  __ICCRX__
    EI();
#elif   __CCRX__
    set_ipl(0); /* set lowest IPL level */
    setpsw_i();  // enable interrput
#else
    //
#endif

    while (1)
    {
        int32_t i;
        
        wt = wt + dwt;
        if (wt>TWOPI) { wt = wt - TWOPI; }
        
        if (up==1)
        {
             m = m + dm;
             if (m>=1.0f) { up = 0; }
        }
        else
        {
             m = m - dm;
             if (m<=0.5f) { up = 1; }
        }

        refu  = m * sinf(wt);
        refv  = m * sinf(wt-TWOPI*1.0f/3.0f);
        refw  = m * sinf(wt-TWOPI*2.0f/3.0f);

        for(i=0;i<5000;i++) { nop(); }

        ics2_watchpoint();
    }
}
